@@ -45,4 +45,4 @@ def main() -> bool:
 
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
